require_relative '../helper'

class TestServer < TestCase

  def test_create_instance_server
    s = Server.new name: "web"
    instance = s.create_instance!
    assert_kind_of(Instance, instance)
    assert_equal(instance.server, s)
  end

  def test_find_all
    servers = Server.all
    assert_equal 1, servers.count
  end

  def test_ssh_key
    server = Server.new ssh_key: "web"
    assert_not_nil(server.ssh_key)
    assert_kind_of(KeyReference, server.ssh_key)
    assert_respond_to(server.ssh_key, :private)
    assert_respond_to(server.ssh_key, :public)
  end

  def test_server_env_options
    env = {
      development: {
        ssh_key: 'dev'
      },
      production: {
        ssh_key: 'prod'
      }
    }
    server = Server.new environments: env
    assert_equal server.ssh_key.name, 'dev'

    Asteroid.environment = :production

    server = Server.new environments: env
    assert_equal server.ssh_key.name, 'prod'
  end

  def test_instance_options
    config = {
      "whatever" => 123,
      "something" => "else"
    }
    s = Server.new name: "web", instance_options: config
    assert_equal config, s.instance_options
  end

  def test_commands
    commands = {
      "two" => ['add 1 1'],
      "add-two" => {"args" => ['a'], "steps" => ['add $a 2']},
      "something" => ['run something', 'do thing']
    }
    @s = Server.new name: "web", commands: commands
    assert_equal commands, @s.commands
  end

  def test_command_instance
    test_commands
    instance = @s.create_instance!
    assert_equal "2", instance.eval_command("two")
    assert_equal "4", instance.eval_command("add-two 2")
  end

  def test_generate_name
    s = Server.new name: "hyperlinks"
    
    Asteroid::Config.namespace = nil
    name = s.generate_instance_name
    assert_equal "hyperlinks", name.split('-').first

    Asteroid::Config.namespace = "wowcool"
    name = s.generate_instance_name
    assert_equal "wowcool:hyperlinks", name.split('-').first

    i = s.create_instance!
    assert_equal "wowcool", i.namespace
  end

  def test_server_type
    s = Server.new name: "web"
    assert_equal :web, s.type
  end

  def test_create_server
    cobol = Server.new name: "cobol"
    instance = cobol.create_instance!
    assert_equal(instance.server, cobol)
    assert_equal(:cobol, instance.type)
  end

end